@@ -1,3 +1,3 @@
-# flake8:noqas
 from .automl_search import AutoMLSearch
+from .utils import get_default_primary_search_objective
 from .data_splitters import TrainingValidationSplit
