@@ -17,7 +17,13 @@ from .pipeline_search_plots import PipelineSearchPlots
 
 from evalml.automl.automl_algorithm import IterativeAlgorithm
 from evalml.automl.data_splitters import TrainingValidationSplit
-from evalml.data_checks import DataChecks, DefaultDataChecks, EmptyDataChecks
+from evalml.automl.utils import get_default_primary_search_objective
+from evalml.data_checks import (
+    AutoMLDataChecks,
+    DataChecks,
+    DefaultDataChecks,
+    EmptyDataChecks
+)
 from evalml.data_checks.data_check_message_type import DataCheckMessageType
 from evalml.exceptions import (
     AutoMLSearchException,
@@ -25,21 +31,9 @@ from evalml.exceptions import (
     PipelineScoreError
 )
 from evalml.objectives import (
-    CostBenefitMatrix,
-    FraudCost,
-    LeadScoring,
-    MeanSquaredLogError,
-    Recall,
-    RecallMacro,
-    RecallMicro,
-    RecallWeighted,
-    RootMeanSquaredLogError,
-    get_objective,
-    get_objectives
-)
-from evalml.objectives.utils import (
-    _all_objectives_dict,
-    _print_objectives_in_table
+    get_core_objectives,
+    get_non_core_objectives,
+    get_objective
 )
 from evalml.pipelines import (
     BinaryClassificationPipeline,
@@ -52,7 +46,6 @@ from evalml.pipelines.utils import make_pipeline
 from evalml.problem_types import ProblemTypes, handle_problem_types
 from evalml.tuners import SKOptTuner
 from evalml.utils import convert_to_seconds, get_random_state
-from evalml.utils.gen_utils import classproperty
 from evalml.utils.logger import (
     get_logger,
     log_subtitle,
@@ -68,18 +61,16 @@ class AutoMLSearch:
     """Automated Pipeline search."""
     _MAX_NAME_LEN = 40
     _LARGE_DATA_ROW_THRESHOLD = int(1e5)
+    _LARGE_DATA_PERCENT_VALIDATION = 0.75
 
     # Necessary for "Plotting" documentation, since Sphinx does not work well with instance attributes.
     plot = PipelineSearchPlots
 
-    _DEFAULT_OBJECTIVES = {'binary': 'Log Loss Binary',
-                           'multiclass': 'Log Loss Multiclass',
-                           'regression': 'R2'}
-
     def __init__(self,
                  problem_type=None,
                  objective='auto',
                  max_pipelines=None,
+                 max_iterations=None,
                  max_time=None,
                  patience=None,
                  tolerance=None,
@@ -100,14 +91,19 @@ class AutoMLSearch:
         Arguments:
             problem_type (str or ProblemTypes): Choice of 'regression', 'binary', or 'multiclass', depending on the desired problem type.
 
-            objective (str, ObjectiveBase): The objective to optimize for. When set to auto, chooses:
-                LogLossBinary for binary classification problems,
-                LogLossMulticlass for multiclass classification problems, and
-                R2 for regression problems.
+            objective (str, ObjectiveBase): The objective to optimize for. Used to propose and rank pipelines, but not for optimizing each pipeline during fit-time.
+                When set to 'auto', chooses:
 
-            max_pipelines (int): Maximum number of pipelines to search. If max_pipelines and
+                - LogLossBinary for binary classification problems,
+                - LogLossMulticlass for multiclass classification problems, and
+                - R2 for regression problems.
+
+            max_pipelines (int): Will be deprecated in the next release. Maximum number of pipelines to search. If max_pipelines and
                 max_time is not set, then max_pipelines will default to max_pipelines of 5.
 
+            max_iterations (int): Maximum number of iterations to search. If max_iterations and
+                max_time is not set, then max_iterations will default to max_iterations of 5.
+
             max_time (int, str): Maximum time to search for pipelines.
                 This will not start a new pipeline search after the duration
                 has elapsed. If it is an integer, then the time will be in seconds.
@@ -149,7 +145,7 @@ class AutoMLSearch:
             verbose (boolean): If True, turn verbosity on. Defaults to True
 
             _max_batches (int): The maximum number of batches of pipelines to search. Parameters max_time, and
-                max_pipelines have precedence over stopping the search.
+                max_iterations have precedence over stopping the search.
         """
         try:
             self.problem_type = handle_problem_types(problem_type)
@@ -163,7 +159,7 @@ class AutoMLSearch:
         self.verbose = verbose
         self.optimize_thresholds = optimize_thresholds
         if objective == 'auto':
-            objective = self._DEFAULT_OBJECTIVES[self.problem_type.value]
+            objective = get_default_primary_search_objective(self.problem_type.value)
         objective = get_objective(objective, return_instance=False)
         self.objective = self._validate_objective(objective)
         if self.data_split is not None and not issubclass(self.data_split.__class__, BaseCrossValidator):
@@ -171,7 +167,7 @@ class AutoMLSearch:
         if self.problem_type != self.objective.problem_type:
             raise ValueError("Given objective {} is not compatible with a {} problem.".format(self.objective.name, self.problem_type.value))
         if additional_objectives is None:
-            additional_objectives = [obj for obj in get_objectives(self.problem_type) if obj not in self._objectives_not_allowed_in_automl]
+            additional_objectives = get_core_objectives(self.problem_type)
             # if our main objective is part of default set of objectives for problem_type, remove it
             existing_main_objective = next((obj for obj in additional_objectives if obj.name == self.objective.name), None)
             if existing_main_objective is not None:
@@ -188,10 +184,15 @@ class AutoMLSearch:
         else:
             raise TypeError("max_time must be a float, int, or string. Received a {}.".format(type(max_time)))
 
-        self.max_pipelines = max_pipelines
-        if self.max_pipelines is None and self.max_time is None and _max_batches is None:
-            self.max_pipelines = 5
-            logger.info("Using default limit of max_pipelines=5.\n")
+        if max_pipelines:
+            if not max_iterations:
+                max_iterations = max_pipelines
+            logger.warning("`max_pipelines` will be deprecated in the next release. Use `max_iterations` instead.")
+
+        self.max_iterations = max_iterations
+        if not self.max_iterations and not self.max_time and not _max_batches:
+            self.max_iterations = 5
+            logger.info("Using default limit of max_iterations=5.\n")
 
         if patience and (not isinstance(patience, int) or patience < 0):
             raise ValueError("patience value must be a positive integer. Received {} instead".format(patience))
@@ -223,7 +224,7 @@ class AutoMLSearch:
         self._baseline_cv_score = None
 
         if _max_batches is not None and _max_batches <= 0:
-            raise ValueError("Parameter max batches must be None or non-negative. Received {max_batches}.")
+            raise ValueError(f"Parameter max batches must be None or non-negative. Received {_max_batches}.")
         self._max_batches = _max_batches
         # This is the default value for IterativeAlgorithm - setting this explicitly makes sure that
         # the behavior of max_batches does not break if IterativeAlgorithm is changed.
@@ -231,21 +232,12 @@ class AutoMLSearch:
 
         self._validate_problem_type()
 
-    @classproperty
-    def _objectives_not_allowed_in_automl(self):
-        return {CostBenefitMatrix, FraudCost, LeadScoring,
-                MeanSquaredLogError, Recall, RecallMacro, RecallMicro, RecallWeighted, RootMeanSquaredLogError}
-
-    @classmethod
-    def print_objective_names_allowed_in_automl(cls):
-        names = [name for name, value in _all_objectives_dict().items() if value not in cls._objectives_not_allowed_in_automl]
-        _print_objectives_in_table(names)
-
     def _validate_objective(self, objective):
+        non_core_objectives = get_non_core_objectives()
         if isinstance(objective, type):
-            if objective in self._objectives_not_allowed_in_automl:
-                raise ValueError(f"{objective.name} is not allowed in AutoML! "
-                                 "Use evalml.automl.AutoMLSearch.print_objective_names_allowed_in_automl() "
+            if objective in non_core_objectives:
+                raise ValueError(f"{objective.name.lower()} is not allowed in AutoML! "
+                                 "Use evalml.objectives.utils.get_core_objective_names()"
                                  "to get all objective names allowed in automl.")
             return objective()
         return objective
@@ -270,7 +262,7 @@ class AutoMLSearch:
             f"Parameters: \n{'='*20}\n"
             f"Objective: {get_objective(self.objective).name}\n"
             f"Max Time: {self.max_time}\n"
-            f"Max Pipelines: {self.max_pipelines}\n"
+            f"Max Iterations: {self.max_iterations}\n"
             f"Allowed Pipelines: \n{_print_list(self.allowed_pipelines or [])}\n"
             f"Patience: {self.patience}\n"
             f"Tolerance: {self.tolerance}\n"
@@ -292,8 +284,7 @@ class AutoMLSearch:
 
         return search_desc + rankings_desc
 
-    @staticmethod
-    def _validate_data_checks(data_checks):
+    def _validate_data_checks(self, data_checks):
         """Validate data_checks parameter.
 
         Arguments:
@@ -306,10 +297,10 @@ class AutoMLSearch:
         if isinstance(data_checks, DataChecks):
             return data_checks
         elif isinstance(data_checks, list):
-            return DataChecks(data_checks)
+            return AutoMLDataChecks(data_checks)
         elif isinstance(data_checks, str):
             if data_checks == "auto":
-                return DefaultDataChecks()
+                return DefaultDataChecks(problem_type=self.problem_type)
             elif data_checks == "disabled":
                 return EmptyDataChecks()
             else:
@@ -323,7 +314,7 @@ class AutoMLSearch:
     def _handle_keyboard_interrupt(self, pipeline, current_batch_pipelines):
         """Presents a prompt to the user asking if they want to stop the search.
 
-        Args:
+        Arguments:
             pipeline (PipelineBase): Current pipeline in the search.
             current_batch_pipelines (list): Other pipelines in the batch.
 
@@ -352,7 +343,7 @@ class AutoMLSearch:
         Arguments:
             X (pd.DataFrame): the input training data of shape [n_samples, n_features]
 
-            y (pd.Series): the target training labels of length [n_samples]
+            y (pd.Series): the target training data of length [n_samples]
 
             feature_types (list, optional): list of feature types, either numerical or categorical.
                 Categorical features will automatically be encoded
@@ -389,7 +380,7 @@ class AutoMLSearch:
             default_data_split = StratifiedKFold(n_splits=3, random_state=self.random_state)
 
         if X.shape[0] > self._LARGE_DATA_ROW_THRESHOLD:
-            default_data_split = TrainingValidationSplit(test_size=0.25)
+            default_data_split = TrainingValidationSplit(test_size=self._LARGE_DATA_PERCENT_VALIDATION)
 
         self.data_split = self.data_split or default_data_split
 
@@ -414,8 +405,8 @@ class AutoMLSearch:
 
         if self.allowed_pipelines == []:
             raise ValueError("No allowed pipelines to search")
-        if self._max_batches and self.max_pipelines is None:
-            self.max_pipelines = 1 + len(self.allowed_pipelines) + (self._pipelines_per_batch * (self._max_batches - 1))
+        if self._max_batches and self.max_iterations is None:
+            self.max_iterations = 1 + len(self.allowed_pipelines) + (self._pipelines_per_batch * (self._max_batches - 1))
 
         self.allowed_model_families = list(set([p.model_family for p in (self.allowed_pipelines)]))
 
@@ -423,7 +414,7 @@ class AutoMLSearch:
         logger.debug(f"allowed_model_families set to {self.allowed_model_families}")
 
         self._automl_algorithm = IterativeAlgorithm(
-            max_pipelines=self.max_pipelines,
+            max_iterations=self.max_iterations,
             allowed_pipelines=self.allowed_pipelines,
             tuner_class=self.tuner_class,
             random_state=self.random_state,
@@ -436,8 +427,8 @@ class AutoMLSearch:
         logger.info("Optimizing for %s. " % self.objective.name)
         logger.info("{} score is better.\n".format('Greater' if self.objective.greater_is_better else 'Lower'))
 
-        if self.max_pipelines is not None:
-            logger.info("Searching up to %s pipelines. " % self.max_pipelines)
+        if self.max_iterations is not None:
+            logger.info("Searching up to %s pipelines. " % self.max_iterations)
         if self.max_time is not None:
             logger.info("Will stop searching for new pipelines after %d seconds.\n" % self.max_time)
         logger.info("Allowed model families: %s\n" % ", ".join([model.value for model in self.allowed_model_families]))
@@ -476,7 +467,7 @@ class AutoMLSearch:
                     desc = desc[:self._MAX_NAME_LEN - 3] + "..."
                 desc = desc.ljust(self._MAX_NAME_LEN)
 
-                update_pipeline(logger, desc, len(self._results['pipeline_results']) + 1, self.max_pipelines, self._start)
+                update_pipeline(logger, desc, len(self._results['pipeline_results']) + 1, self.max_iterations, self._start)
 
                 evaluation_results = self._evaluate(pipeline, X, y)
                 score = evaluation_results['cv_score_mean']
@@ -506,11 +497,11 @@ class AutoMLSearch:
         should_continue = True
         num_pipelines = len(self._results['pipeline_results'])
 
-        # check max_time and max_pipelines
+        # check max_time and max_iterations
         elapsed = time.time() - start
         if self.max_time and elapsed >= self.max_time:
             return False
-        elif self.max_pipelines and num_pipelines >= self.max_pipelines:
+        elif self.max_iterations and num_pipelines >= self.max_iterations:
             return False
 
         # check for early stopping
@@ -550,7 +541,7 @@ class AutoMLSearch:
 
         Arguments:
             X (pd.DataFrame): the input training data of shape [n_samples, n_features]
-            y (pd.Series): the target training labels of length [n_samples]
+            y (pd.Series): the target training data of length [n_samples]
 
         Returns:
             bool - If the user ends the search early, will return True and searching will immediately finish. Else,
@@ -577,7 +568,7 @@ class AutoMLSearch:
                     desc = desc[:self._MAX_NAME_LEN - 3] + "..."
                 desc = desc.ljust(self._MAX_NAME_LEN)
 
-                update_pipeline(logger, desc, len(self._results['pipeline_results']) + 1, self.max_pipelines,
+                update_pipeline(logger, desc, len(self._results['pipeline_results']) + 1, self.max_iterations,
                                 self._start)
 
                 baseline_results = self._compute_cv_scores(baseline, X, y)
@@ -602,6 +593,13 @@ class AutoMLSearch:
             logger.debug(f"\t\tTraining and scoring on fold {i}")
             X_train, X_test = X.iloc[train], X.iloc[test]
             y_train, y_test = y.iloc[train], y.iloc[test]
+            if self.problem_type in [ProblemTypes.BINARY, ProblemTypes.MULTICLASS]:
+                diff_train = set(np.setdiff1d(y, y_train))
+                diff_test = set(np.setdiff1d(y, y_test))
+                diff_string = f"Missing target values in the training set after data split: {diff_train}. " if diff_train else ""
+                diff_string += f"Missing target values in the test set after data split: {diff_test}." if diff_test else ""
+                if diff_string:
+                    raise Exception(diff_string)
             objectives_to_score = [self.objective] + self.additional_objectives
             cv_pipeline = None
             try:
@@ -688,7 +686,8 @@ class AutoMLSearch:
             "high_variance_cv": high_variance_cv,
             "training_time": training_time,
             "cv_data": cv_data,
-            "percent_better_than_baseline": percent_better
+            "percent_better_than_baseline": percent_better,
+            "validation_score": cv_scores[0]
         }
         self._results['search_order'].append(pipeline_id)
 
@@ -792,7 +791,7 @@ class AutoMLSearch:
 
             X (pd.DataFrame): the input training data of shape [n_samples, n_features].
 
-            y (pd.Series): the target training labels of length [n_samples].
+            y (pd.Series): the target training data of length [n_samples].
         """
         if not isinstance(X, pd.DataFrame):
             X = pd.DataFrame(X)
@@ -835,8 +834,8 @@ class AutoMLSearch:
         if self.objective.greater_is_better:
             ascending = False
 
-        full_rankings_cols = ["id", "pipeline_name", "score", "percent_better_than_baseline",
-                              "high_variance_cv", "parameters"]
+        full_rankings_cols = ["id", "pipeline_name", "score", "validation_score",
+                              "percent_better_than_baseline", "high_variance_cv", "parameters"]
         if not self.has_searched:
             return pd.DataFrame(columns=full_rankings_cols)
 
