@@ -9,6 +9,7 @@ class ModelFamily(Enum):
     LINEAR_MODEL = 'linear_model'
     CATBOOST = 'catboost'
     EXTRA_TREES = 'extra_trees'
+    DECISION_TREE = 'decision_tree'
     BASELINE = 'baseline'
     NONE = 'none'
 
@@ -19,6 +20,7 @@ class ModelFamily(Enum):
                              ModelFamily.LINEAR_MODEL.name: "Linear",
                              ModelFamily.CATBOOST.name: "CatBoost",
                              ModelFamily.EXTRA_TREES.name: "Extra Trees",
+                             ModelFamily.DECISION_TREE.name: "Decision Tree",
                              ModelFamily.BASELINE.name: "Baseline",
                              ModelFamily.NONE.name: "None"}
         return model_family_dict[self.name]
@@ -27,7 +29,7 @@ class ModelFamily(Enum):
         return "ModelFamily." + self.name
 
     def is_tree_estimator(self):
-        """Checks whether the estimator's model family uses tree ensembles."""
+        """Checks whether the estimator's model family uses trees."""
         tree_estimators = {self.CATBOOST, self.EXTRA_TREES, self.RANDOM_FOREST,
-                           self.XGBOOST, self.LIGHTGBM}
+                           self.DECISION_TREE, self.XGBOOST, self.LIGHTGBM}
         return self in tree_estimators
