@@ -26,8 +26,8 @@ def confusion_matrix(y_true, y_predicted, normalize_method='true'):
     """Confusion matrix for binary and multiclass classification.
 
     Arguments:
-        y_true (pd.Series or np.array): true binary labels.
-        y_pred (pd.Series or np.array): predictions from a binary classifier.
+        y_true (pd.Series or np.array): True binary labels.
+        y_pred (pd.Series or np.array): Predictions from a binary classifier.
         normalize_method ({'true', 'pred', 'all'}): Normalization method. Supported options are: 'true' to normalize by row, 'pred' to normalize by column, or 'all' to normalize by all values. Defaults to 'true'.
 
     Returns:
@@ -50,7 +50,7 @@ def normalize_confusion_matrix(conf_mat, normalize_method='true'):
     """Normalizes a confusion matrix.
 
     Arguments:
-        conf_mat (pd.DataFrame or np.array): confusion matrix to normalize.
+        conf_mat (pd.DataFrame or np.array): Confusion matrix to normalize.
         normalize_method ({'true', 'pred', 'all'}): Normalization method. Supported options are: 'true' to normalize by row, 'pred' to normalize by column, or 'all' to normalize by all values. Defaults to 'true'.
 
     Returns:
@@ -75,8 +75,8 @@ def precision_recall_curve(y_true, y_pred_proba):
     Given labels and binary classifier predicted probabilities, compute and return the data representing a precision-recall curve.
 
     Arguments:
-        y_true (pd.Series or np.array): true binary labels.
-        y_pred_proba (pd.Series or np.array): predictions from a binary classifier, before thresholding has been applied. Note this should be the predicted probability for the "true" label.
+        y_true (pd.Series or np.array): True binary labels.
+        y_pred_proba (pd.Series or np.array): Predictions from a binary classifier, before thresholding has been applied. Note this should be the predicted probability for the "true" label.
 
     Returns:
         list: Dictionary containing metrics used to generate a precision-recall plot, with the following keys:
@@ -98,9 +98,9 @@ def graph_precision_recall_curve(y_true, y_pred_proba, title_addition=None):
     """Generate and display a precision-recall plot.
 
     Arguments:
-        y_true (pd.Series or np.array): true binary labels.
-        y_pred_proba (pd.Series or np.array): predictions from a binary classifier, before thresholding has been applied. Note this should be the predicted probability for the "true" label.
-        title_addition (str or None): if not None, append to plot title. Default None.
+        y_true (pd.Series or np.array): True binary labels.
+        y_pred_proba (pd.Series or np.array): Predictions from a binary classifier, before thresholding has been applied. Note this should be the predicted probability for the "true" label.
+        title_addition (str or None): If not None, append to plot title. Default None.
 
     Returns:
         plotly.Figure representing the precision-recall plot generated
@@ -131,8 +131,8 @@ def roc_curve(y_true, y_pred_proba):
     Given labels and classifier predicted probabilities, compute and return the data representing a Receiver Operating Characteristic (ROC) curve. Works with binary or multiclass problems.
 
     Arguments:
-        y_true (pd.Series or np.array): true labels.
-        y_pred_proba (pd.DataFrame, pd.Series, or np.array): predictions from a classifier, before thresholding has been applied.
+        y_true (pd.Series or np.array): True labels.
+        y_pred_proba (pd.Series or np.array): Predictions from a classifier, before thresholding has been applied.
 
     Returns:
         list(dict): A list of dictionaries (with one for each class) is returned. Binary classification problems return a list with one dictionary.
@@ -177,9 +177,9 @@ def graph_roc_curve(y_true, y_pred_proba, custom_class_names=None, title_additio
     """Generate and display a Receiver Operating Characteristic (ROC) plot for binary and multiclass classification problems.
 
     Arguments:
-        y_true (pd.Series or np.array): true labels.
-        y_pred_proba (pd.Series or np.array): predictions from a classifier, before thresholding has been applied. Note this should a one dimensional array with the predicted probability for the "true" label in the binary case.
-        custom_class_labels (list or None): if not None, custom labels for classes. Default None.
+        y_true (pd.Series or np.array): True labels.
+        y_pred_proba (pd.Series or np.array): Predictions from a classifier, before thresholding has been applied. Note this should a one dimensional array with the predicted probability for the "true" label in the binary case.
+        custom_class_labels (list or None): If not None, custom labels for classes. Default None.
         title_addition (str or None): if not None, append to plot title. Default None.
 
     Returns:
@@ -222,8 +222,8 @@ def graph_confusion_matrix(y_true, y_pred, normalize_method='true', title_additi
     If `normalize_method` is set, hover text will show raw count, otherwise hover text will show count normalized with method 'true'.
 
     Arguments:
-        y_true (pd.Series or np.array): true binary labels.
-        y_pred (pd.Series or np.array): predictions from a binary classifier.
+        y_true (pd.Series or np.array): True binary labels.
+        y_pred (pd.Series or np.array): Predictions from a binary classifier.
         normalize_method ({'true', 'pred', 'all'}): Normalization method. Supported options are: 'true' to normalize by row, 'pred' to normalize by column, or 'all' to normalize by all values. Defaults to 'true'.
         title_addition (str or None): if not None, append to plot title. Default None.
 
@@ -268,10 +268,10 @@ def calculate_permutation_importance(pipeline, X, y, objective, n_repeats=5, n_j
     """Calculates permutation importance for features.
 
     Arguments:
-        pipeline (PipelineBase or subclass): fitted pipeline
-        X (pd.DataFrame): the input data used to score and compute permutation importance
-        y (pd.Series): the target labels
-        objective (str, ObjectiveBase): objective to score on
+        pipeline (PipelineBase or subclass): Fitted pipeline
+        X (pd.DataFrame): The input data used to score and compute permutation importance
+        y (pd.Series): The target data
+        objective (str, ObjectiveBase): Objective to score on
         n_repeats (int): Number of times to permute a feature. Defaults to 5.
         n_jobs (int or None): Non-negative integer describing level of parallelism used for pipelines.
             None and 1 are equivalent. If set to -1, all CPUs are used. For n_jobs below -1, (n_cpus + 1 + n_jobs) are used.
@@ -303,7 +303,7 @@ def graph_permutation_importance(pipeline, X, y, objective, importance_threshold
     Arguments:
         pipeline (PipelineBase or subclass): Fitted pipeline
         X (pd.DataFrame): The input data used to score and compute permutation importance
-        y (pd.Series): The target labels
+        y (pd.Series): The target data
         objective (str, ObjectiveBase): Objective to score on
         importance_threshold (float, optional): If provided, graph features with a permutation importance whose absolute value is larger than importance_threshold. Defaults to zero.
 
@@ -352,10 +352,10 @@ def binary_objective_vs_threshold(pipeline, X, y, objective, steps=100):
         decision thresholds for a fitted binary classification pipeline.
 
     Arguments:
-        pipeline (BinaryClassificationPipeline obj): fitted binary classification pipeline
-        X (pd.DataFrame): the input data used to compute objective score
-        y (pd.Series): the target labels
-        objective (ObjectiveBase obj, str): objective used to score
+        pipeline (BinaryClassificationPipeline obj): Fitted binary classification pipeline
+        X (pd.DataFrame): The input data used to compute objective score
+        y (pd.Series): The target labels
+        objective (ObjectiveBase obj, str): Objective used to score
         steps (int): Number of intervals to divide and calculate objective score at
 
     Returns:
@@ -383,10 +383,10 @@ def graph_binary_objective_vs_threshold(pipeline, X, y, objective, steps=100):
     """Generates a plot graphing objective score vs. decision thresholds for a fitted binary classification pipeline.
 
     Arguments:
-        pipeline (PipelineBase or subclass): fitted pipeline
-        X (pd.DataFrame): the input data used to score and compute scores
-        y (pd.Series): the target labels
-        objective (ObjectiveBase obj, str): objective used to score, shown on the y-axis of the graph
+        pipeline (PipelineBase or subclass): Fitted pipeline
+        X (pd.DataFrame): The input data used to score and compute scores
+        y (pd.Series): The target labels
+        objective (ObjectiveBase obj, str): Objective used to score, shown on the y-axis of the graph
         steps (int): Number of intervals to divide and calculate objective score at
 
     Returns:
@@ -415,7 +415,7 @@ def partial_dependence(pipeline, X, feature, grid_resolution=100):
 
     Arguments:
         pipeline (PipelineBase or subclass): Fitted pipeline
-        X (pd.DataFrame, npermutation importance.array): The input data used to generate a grid of values
+        X (pd.DataFrame, np.array): The input data used to generate a grid of values
             for feature where partial dependence will be calculated at
         feature (int, string): The target features for which to create the partial dependence plot for.
             If feature is an int, it must be the index of the feature to use.
@@ -426,24 +426,23 @@ def partial_dependence(pipeline, X, feature, grid_resolution=100):
             over all samples of X and the values used to calculate those predictions.
 
     """
-    if pipeline.model_family == ModelFamily.BASELINE:
-        raise ValueError("Partial dependence plots are not supported for Baseline pipelines")
+    if not isinstance(X, pd.DataFrame):
+        X = pd.DataFrame(X)
     if not pipeline._is_fitted:
         raise ValueError("Pipeline to calculate partial dependence for must be fitted")
-    if pipeline.model_family == ModelFamily.CATBOOST:
-        pipeline.estimator._component_obj._fitted_ = True
-    if pipeline.model_family == ModelFamily.XGBOOST:
-        if isinstance(pipeline, evalml.pipelines.ClassificationPipeline):
-            pipeline.estimator._estimator_type = "classifier"
-            # set arbitrary attribute that ends in underscore to pass scikit-learn check for is_fitted
-            pipeline.estimator.classes_ = pipeline.classes_
-        elif isinstance(pipeline, evalml.pipelines.RegressionPipeline):
-            pipeline.estimator._estimator_type = "regressor"
-            # set arbitrary attribute that ends in underscore to pass scikit-learn check for is_fitted
-            pipeline.estimator.feature_importances_ = pipeline.feature_importance
-        avg_pred, values = sk_partial_dependence(pipeline.estimator, X=X, features=[feature], grid_resolution=grid_resolution)
-    else:
-        avg_pred, values = sk_partial_dependence(pipeline.estimator._component_obj, X=X, features=[feature], grid_resolution=grid_resolution)
+    if pipeline.model_family == ModelFamily.BASELINE:
+        raise ValueError("Partial dependence plots are not supported for Baseline pipelines")
+    if isinstance(pipeline, evalml.pipelines.ClassificationPipeline):
+        pipeline._estimator_type = "classifier"
+    elif isinstance(pipeline, evalml.pipelines.RegressionPipeline):
+        pipeline._estimator_type = "regressor"
+    pipeline.feature_importances_ = pipeline.feature_importance
+    try:
+        avg_pred, values = sk_partial_dependence(pipeline, X=X, features=[feature], grid_resolution=grid_resolution)
+    finally:
+        # Delete scikit-learn attributes that were temporarily set
+        del pipeline._estimator_type
+        del pipeline.feature_importances_
     return pd.DataFrame({"feature_values": values[0],
                          "partial_dependence": avg_pred[0]})
 
@@ -453,14 +452,14 @@ def graph_partial_dependence(pipeline, X, feature, grid_resolution=100):
 
     Arguments:
         pipeline (PipelineBase or subclass): Fitted pipeline
-        X (pd.DataFrame, npermutation importance.array): The input data used to generate a grid of values
+        X (pd.DataFrame, np.array): The input data used to generate a grid of values
             for feature where partial dependence will be calculated at
         feature (int, string): The target feature for which to create the partial dependence plot for.
             If feature is an int, it must be the index of the feature to use.
             If feature is a string, it must be a valid column name in X.
 
     Returns:
-        pd.DataFrame: DataFrame with averaged predictions for all points in the grid averaged
+        pd.DataFrame: pd.DataFrame with averaged predictions for all points in the grid averaged
             over all samples of X and the values used to calculate those predictions.
 
     """
