@@ -1,12 +1,26 @@
-from texttable import Texttable
 
 from .objective_base import ObjectiveBase
 
+from evalml import objectives
 from evalml.exceptions import ObjectiveNotFoundError
 from evalml.problem_types import handle_problem_types
 from evalml.utils.gen_utils import _get_subclasses
 
 
+def get_non_core_objectives():
+    """Get non-core objective classes.
+
+    Non-core objectives are objectives that are domain-specific. Users typically need to configure these objectives
+    before using them in AutoMLSearch.
+
+    Returns:
+        List of ObjectiveBase classes
+    """
+    return [objectives.CostBenefitMatrix, objectives.FraudCost, objectives.LeadScoring,
+            objectives.MeanSquaredLogError, objectives.Recall, objectives.RecallMacro, objectives.RecallMicro,
+            objectives.RecallWeighted, objectives.RootMeanSquaredLogError]
+
+
 def _all_objectives_dict():
     all_objectives = _get_subclasses(ObjectiveBase)
     objectives_dict = {}
@@ -17,43 +31,35 @@ def _all_objectives_dict():
     return objectives_dict
 
 
-def _print_objectives_in_table(names):
-    """Print the list of objective names in a table.
+def get_all_objective_names():
+    """Get a list of the names of all objectives.
 
     Returns:
-         None
-    """
-    def iterate_in_batches(sequence, batch_size):
-        return [sequence[pos:pos + batch_size] for pos in range(0, len(sequence), batch_size)]
-    batch_size = 4
-    table = Texttable()
-    table.set_deco(Texttable.BORDER | Texttable.HLINES | Texttable.VLINES)
-    for row in iterate_in_batches(sorted(names), batch_size):
-        if len(row) < batch_size:
-            row += [""] * (batch_size - len(row))
-        table.add_row(row)
-    print(table.draw())
-
-
-def print_all_objective_names():
-    """Get all valid objective names in a table.
-
-    Returns:
-        None
+        list (str): Objective names
     """
     all_objectives_dict = _all_objectives_dict()
-    all_names = list(all_objectives_dict.keys())
-    _print_objectives_in_table(all_names)
+    return list(all_objectives_dict.keys())
+
+
+def get_core_objective_names():
+    """Get a list of all valid core objectives.
+
+    Returns:
+        list(str): Objective names.
+    """
+    all_objectives = _all_objectives_dict()
+    non_core = get_non_core_objectives()
+    return [name for name, class_name in all_objectives.items() if class_name not in non_core]
 
 
 def get_objective(objective, return_instance=False, **kwargs):
-    """Returns the Objective object of the given objective name
+    """Returns the Objective class corresponding to a given objective name.
 
     Arguments:
-        objective (str or ObjectiveBase): name or instance of the objective class.
+        objective (str or ObjectiveBase): Name or instance of the objective class.
         return_instance (bool): Whether to return an instance of the objective. This only applies if objective
             is of type str. Note that the instance will be initialized with default arguments.
-        **kwargs (Any): Any keyword arguments to pass into the objective. Only used when return_instance=True.
+        kwargs (Any): Any keyword arguments to pass into the objective. Only used when return_instance=True.
 
     Returns:
         ObjectiveBase if the parameter objective is of type ObjectiveBase. If objective is instead a valid
@@ -69,7 +75,7 @@ def get_objective(objective, return_instance=False, **kwargs):
         raise TypeError("If parameter objective is not a string, it must be an instance of ObjectiveBase!")
     if objective.lower() not in all_objectives_dict:
         raise ObjectiveNotFoundError(f"{objective} is not a valid Objective! "
-                                     "Use evalml.objectives.print_all_objective_names(allowed_in_automl=False)"
+                                     "Use evalml.objectives.get_all_objective_names()"
                                      "to get a list of all valid objective names. ")
 
     objective_class = all_objectives_dict[objective.lower()]
@@ -83,16 +89,18 @@ def get_objective(objective, return_instance=False, **kwargs):
     return objective_class
 
 
-def get_objectives(problem_type):
-    """Returns all objective classes associated with the given problem type.
+def get_core_objectives(problem_type):
+    """Returns all core objective instances associated with the given problem type.
 
-    Args:
-        problem_type (str/ProblemTypes): type of problem
+    Core objectives are designed to work out-of-the-box for any dataset.
+
+    Arguments:
+        problem_type (str/ProblemTypes): Type of problem
 
     Returns:
-        List of Objectives
+        List of ObjectiveBase instances
     """
     problem_type = handle_problem_types(problem_type)
     all_objectives_dict = _all_objectives_dict()
-    objectives = [obj for obj in all_objectives_dict.values() if obj.problem_type == problem_type]
+    objectives = [obj() for obj in all_objectives_dict.values() if obj.problem_type == problem_type and obj not in get_non_core_objectives()]
     return objectives
