@@ -7,22 +7,31 @@ from evalml.problem_types import ProblemTypes
 
 class BinaryClassificationPipeline(ClassificationPipeline):
     """Pipeline subclass for all binary classification pipelines."""
-    threshold = None
+    _threshold = None
     problem_type = ProblemTypes.BINARY
 
+    @property
+    def threshold(self):
+        """Threshold used to make a prediction. Defaults to None."""
+        return self._threshold
+
+    @threshold.setter
+    def threshold(self, value):
+        self._threshold = value
+
     def _predict(self, X, objective=None):
         """Make predictions using selected features.
 
         Arguments:
-            X (pd.DataFrame or np.array): data of shape [n_samples, n_features]
-            objective (Object or string): the objective to use to make predictions
+            X (pd.DataFrame or np.array): Data of shape [n_samples, n_features]
+            objective (Object or string): The objective to use to make predictions
 
         Returns:
-            pd.Series: estimated labels
+            pd.Series: Estimated labels
         """
         if not isinstance(X, pd.DataFrame):
             X = pd.DataFrame(X)
-        X_t = self._transform(X)
+        X_t = self.compute_estimator_features(X)
 
         if objective is not None:
             objective = get_objective(objective, return_instance=True)
@@ -41,7 +50,7 @@ class BinaryClassificationPipeline(ClassificationPipeline):
         """Make probability estimates for labels. Assumes that the column at index 1 represents the positive label case.
 
         Arguments:
-            X (pd.DataFrame or np.array): data of shape [n_samples, n_features]
+            X (pd.DataFrame or np.array): Data of shape [n_samples, n_features]
 
         Returns:
             pd.DataFrame: probability estimates
