@@ -1,4 +1,3 @@
-# flake8:noqa
 from .logistic_regression import LogisticRegressionClassifier
 from .rf_classifier import RandomForestClassifier
 from .xgboost_classifier import XGBoostClassifier
@@ -7,3 +6,4 @@ from .elasticnet_classifier import ElasticNetClassifier
 from .et_classifier import ExtraTreesClassifier
 from .baseline_classifier import BaselineClassifier
 from .lightgbm_classifier import LightGBMClassifier
+from .decision_tree_classifier import DecisionTreeClassifier
