@@ -1,5 +1,4 @@
 import copy
-import warnings
 
 import numpy as np
 import pandas as pd
@@ -33,16 +32,14 @@ class CatBoostClassifier(Estimator):
     SEED_MAX = SEED_BOUNDS.max_bound
 
     def __init__(self, n_estimators=10, eta=0.03, max_depth=6, bootstrap_type=None, silent=True,
-                 random_state=0, **kwargs):
+                 allow_writing_files=False, random_state=0, **kwargs):
         random_seed = get_random_seed(random_state, self.SEED_MIN, self.SEED_MAX)
         parameters = {"n_estimators": n_estimators,
                       "eta": eta,
                       "max_depth": max_depth,
                       'bootstrap_type': bootstrap_type,
-                      'silent': silent}
-        if kwargs.get('allow_writing_files', False):
-            warnings.warn("Parameter allow_writing_files is being set to False in CatBoostClassifier")
-        kwargs["allow_writing_files"] = False
+                      'silent': silent,
+                      'allow_writing_files': allow_writing_files}
         parameters.update(kwargs)
 
         cb_error_msg = "catboost is not installed. Please install using `pip install catboost.`"
