@@ -1,5 +1,4 @@
 import copy
-import warnings
 
 import pandas as pd
 from skopt.space import Integer, Real
@@ -31,16 +30,14 @@ class CatBoostRegressor(Estimator):
     SEED_MAX = SEED_BOUNDS.max_bound
 
     def __init__(self, n_estimators=10, eta=0.03, max_depth=6, bootstrap_type=None, silent=False,
-                 random_state=0, **kwargs):
+                 allow_writing_files=False, random_state=0, **kwargs):
         random_seed = get_random_seed(random_state, self.SEED_MIN, self.SEED_MAX)
         parameters = {"n_estimators": n_estimators,
                       "eta": eta,
                       "max_depth": max_depth,
                       'bootstrap_type': bootstrap_type,
-                      'silent': silent}
-        if kwargs.get('allow_writing_files', False):
-            warnings.warn("Parameter allow_writing_files is being set to False in CatBoostRegressor")
-        kwargs["allow_writing_files"] = False
+                      'silent': silent,
+                      'allow_writing_files': allow_writing_files}
         parameters.update(kwargs)
 
         cb_error_msg = "catboost is not installed. Please install using `pip install catboost.`"
@@ -56,15 +53,6 @@ class CatBoostRegressor(Estimator):
                          random_state=random_state)
 
     def fit(self, X, y=None):
-        """Build a model
-
-        Arguments:
-            X (pd.DataFrame or np.array): the input training data of shape [n_samples, n_features]
-            y (pd.Series): the target training labels of length [n_samples]
-
-        Returns:
-            self
-        """
         if not isinstance(X, pd.DataFrame):
             X = pd.DataFrame(X)
         if not isinstance(y, pd.Series):
