@@ -89,7 +89,8 @@ class TextFeaturizer(TextTransformer):
 
         Arguments:
             X (pd.DataFrame): Data to transform
-            y (pd.Series, optional): Input Labels
+            y (pd.Series, optional): Ignored.
+
         Returns:
             pd.DataFrame: Transformed X
         """
