@@ -9,7 +9,10 @@ import pytest
 from sklearn.model_selection import StratifiedKFold
 
 from evalml import AutoMLSearch
-from evalml.automl import TrainingValidationSplit
+from evalml.automl import (
+    TrainingValidationSplit,
+    get_default_primary_search_objective
+)
 from evalml.data_checks import (
     DataCheck,
     DataCheckError,
@@ -19,8 +22,14 @@ from evalml.data_checks import (
 from evalml.demos import load_breast_cancer, load_wine
 from evalml.exceptions import AutoMLSearchException, PipelineNotFoundError
 from evalml.model_family import ModelFamily
-from evalml.objectives import FraudCost
-from evalml.objectives.utils import _all_objectives_dict
+from evalml.objectives import (
+    R2,
+    CostBenefitMatrix,
+    FraudCost,
+    LogLossBinary,
+    LogLossMulticlass
+)
+from evalml.objectives.utils import get_core_objectives
 from evalml.pipelines import (
     BinaryClassificationPipeline,
     MulticlassClassificationPipeline,
@@ -39,7 +48,7 @@ from evalml.utils.gen_utils import (
 @pytest.mark.parametrize("automl_type", [ProblemTypes.REGRESSION, ProblemTypes.BINARY, ProblemTypes.MULTICLASS])
 def test_search_results(X_y_regression, X_y_binary, X_y_multi, automl_type):
     expected_cv_data_keys = {'all_objective_scores', 'score', 'binary_classification_threshold'}
-    automl = AutoMLSearch(problem_type=automl_type, max_pipelines=2)
+    automl = AutoMLSearch(problem_type=automl_type, max_iterations=2)
     if automl_type == ProblemTypes.REGRESSION:
         expected_pipeline_class = RegressionPipeline
         X, y = X_y_regression
@@ -56,7 +65,7 @@ def test_search_results(X_y_regression, X_y_binary, X_y_multi, automl_type):
     assert len(automl.results['pipeline_results']) == 2
     for pipeline_id, results in automl.results['pipeline_results'].items():
         assert results.keys() == {'id', 'pipeline_name', 'pipeline_class', 'pipeline_summary', 'parameters', 'score', 'high_variance_cv', 'training_time',
-                                  'cv_data', 'percent_better_than_baseline'}
+                                  'cv_data', 'percent_better_than_baseline', 'validation_score'}
         assert results['id'] == pipeline_id
         assert isinstance(results['pipeline_name'], str)
         assert issubclass(results['pipeline_class'], expected_pipeline_class)
@@ -75,14 +84,15 @@ def test_search_results(X_y_regression, X_y_binary, X_y_multi, automl_type):
             for score in all_objective_scores.values():
                 assert score is not None
         assert automl.get_pipeline(pipeline_id).parameters == results['parameters']
+        assert results['validation_score'] == pd.Series([fold['score'] for fold in results['cv_data']])[0]
     assert isinstance(automl.rankings, pd.DataFrame)
     assert isinstance(automl.full_rankings, pd.DataFrame)
     assert np.all(automl.rankings.dtypes == pd.Series(
-        [np.dtype('int64'), np.dtype('O'), np.dtype('float64'), np.dtype('float64'), np.dtype('bool'), np.dtype('O')],
-        index=['id', 'pipeline_name', 'score', 'percent_better_than_baseline', 'high_variance_cv', 'parameters']))
+        [np.dtype('int64'), np.dtype('O'), np.dtype('float64'), np.dtype('float64'), np.dtype('float64'), np.dtype('bool'), np.dtype('O')],
+        index=['id', 'pipeline_name', 'score', "validation_score", 'percent_better_than_baseline', 'high_variance_cv', 'parameters']))
     assert np.all(automl.full_rankings.dtypes == pd.Series(
-        [np.dtype('int64'), np.dtype('O'), np.dtype('float64'), np.dtype('float64'), np.dtype('bool'), np.dtype('O')],
-        index=['id', 'pipeline_name', 'score', 'percent_better_than_baseline', 'high_variance_cv', 'parameters']))
+        [np.dtype('int64'), np.dtype('O'), np.dtype('float64'), np.dtype('float64'), np.dtype('float64'), np.dtype('bool'), np.dtype('O')],
+        index=['id', 'pipeline_name', 'score', "validation_score", 'percent_better_than_baseline', 'high_variance_cv', 'parameters']))
 
 
 @pytest.mark.parametrize("automl_type", [ProblemTypes.BINARY, ProblemTypes.MULTICLASS, ProblemTypes.REGRESSION])
@@ -108,7 +118,7 @@ def test_pipeline_limits(mock_fit_binary, mock_score_binary,
     mock_score_multi.return_value = {'Log Loss Multiclass': 1.0}
     mock_score_regression.return_value = {'R2': 1.0}
 
-    automl = AutoMLSearch(problem_type=automl_type, max_pipelines=1)
+    automl = AutoMLSearch(problem_type=automl_type, max_iterations=1)
     automl.search(X, y)
     out = caplog.text
     assert "Searching up to 1 pipelines. " in out
@@ -122,7 +132,7 @@ def test_pipeline_limits(mock_fit_binary, mock_score_binary,
     assert len(automl.results['pipeline_results']) >= 1
 
     caplog.clear()
-    automl = AutoMLSearch(problem_type=automl_type, max_time=1, max_pipelines=5)
+    automl = AutoMLSearch(problem_type=automl_type, max_time=1, max_iterations=5)
     automl.search(X, y)
     out = caplog.text
     assert "Searching up to 5 pipelines. " in out
@@ -133,7 +143,7 @@ def test_pipeline_limits(mock_fit_binary, mock_score_binary,
     automl = AutoMLSearch(problem_type=automl_type)
     automl.search(X, y)
     out = caplog.text
-    assert "Using default limit of max_pipelines=5." in out
+    assert "Using default limit of max_iterations=5." in out
     assert len(automl.results['pipeline_results']) <= 5
 
     caplog.clear()
@@ -151,7 +161,7 @@ def test_pipeline_fit_raises(mock_fit, X_y_binary, caplog):
     mock_fit.side_effect = Exception(msg)
     X, y = X_y_binary
 
-    automl = AutoMLSearch(problem_type='binary', max_pipelines=1)
+    automl = AutoMLSearch(problem_type='binary', max_iterations=1)
     automl.search(X, y)
     out = caplog.text
     assert 'Exception during automl search' in out
@@ -172,7 +182,7 @@ def test_pipeline_score_raises(mock_score, X_y_binary, caplog):
     msg = 'all your model are belong to us'
     mock_score.side_effect = Exception(msg)
     X, y = X_y_binary
-    automl = AutoMLSearch(problem_type='binary', max_pipelines=1)
+    automl = AutoMLSearch(problem_type='binary', max_iterations=1)
 
     automl.search(X, y)
     out = caplog.text
@@ -191,7 +201,7 @@ def test_objective_score_raises(mock_score, X_y_binary, caplog):
     msg = 'all your model are belong to us'
     mock_score.side_effect = Exception(msg)
     X, y = X_y_binary
-    automl = AutoMLSearch(problem_type='binary', max_pipelines=1)
+    automl = AutoMLSearch(problem_type='binary', max_iterations=1)
 
     automl.search(X, y)
     out = caplog.text
@@ -209,13 +219,13 @@ def test_objective_score_raises(mock_score, X_y_binary, caplog):
 def test_rankings(X_y_binary, X_y_regression):
     X, y = X_y_binary
     model_families = ['random_forest']
-    automl = AutoMLSearch(problem_type='binary', allowed_model_families=model_families, max_pipelines=3)
+    automl = AutoMLSearch(problem_type='binary', allowed_model_families=model_families, max_iterations=3)
     automl.search(X, y)
     assert len(automl.full_rankings) == 3
     assert len(automl.rankings) == 2
 
     X, y = X_y_regression
-    automl = AutoMLSearch(problem_type='regression', allowed_model_families=model_families, max_pipelines=3)
+    automl = AutoMLSearch(problem_type='regression', allowed_model_families=model_families, max_iterations=3)
     automl.search(X, y)
     assert len(automl.full_rankings) == 3
     assert len(automl.rankings) == 2
@@ -234,7 +244,7 @@ def test_automl_str_search(mock_fit, mock_score, mock_predict_proba, mock_optimi
         'problem_type': 'binary',
         'objective': 'F1',
         'max_time': 100,
-        'max_pipelines': 5,
+        'max_iterations': 5,
         'patience': 2,
         'tolerance': 0.5,
         'allowed_model_families': ['random_forest', 'linear_model'],
@@ -250,7 +260,7 @@ def test_automl_str_search(mock_fit, mock_score, mock_predict_proba, mock_optimi
     param_str_reps = {
         'Objective': search_params['objective'],
         'Max Time': search_params['max_time'],
-        'Max Pipelines': search_params['max_pipelines'],
+        'Max Iterations': search_params['max_iterations'],
         'Allowed Pipelines': [],
         'Patience': search_params['patience'],
         'Tolerance': search_params['tolerance'],
@@ -290,7 +300,7 @@ def test_automl_str_search(mock_fit, mock_score, mock_predict_proba, mock_optimi
 
 
 def test_automl_data_check_results_is_none_before_search():
-    automl = AutoMLSearch(problem_type='binary', max_pipelines=1)
+    automl = AutoMLSearch(problem_type='binary', max_iterations=1)
     assert automl.data_check_results is None
 
 
@@ -303,7 +313,7 @@ def test_automl_empty_data_checks(mock_fit, mock_score):
 
     mock_score.return_value = {'Log Loss Binary': 1.0}
 
-    automl = AutoMLSearch(problem_type="binary", max_pipelines=1)
+    automl = AutoMLSearch(problem_type="binary", max_iterations=1)
 
     automl.search(X, y, data_checks=[])
     assert automl.data_check_results is None
@@ -324,7 +334,7 @@ def test_automl_default_data_checks(mock_fit, mock_score, mock_validate, X_y_bin
     X, y = X_y_binary
     mock_score.return_value = {'Log Loss Binary': 1.0}
     mock_validate.return_value = [DataCheckWarning("default data check warning", "DefaultDataChecks")]
-    automl = AutoMLSearch(problem_type='binary', max_pipelines=1)
+    automl = AutoMLSearch(problem_type='binary', max_iterations=1)
     automl.search(X, y)
     out = caplog.text
     assert "default data check warning" in out
@@ -341,14 +351,14 @@ class MockDataCheckErrorAndWarning(DataCheck):
 
 @pytest.mark.parametrize("data_checks",
                          [[MockDataCheckErrorAndWarning()],
-                          DataChecks([MockDataCheckErrorAndWarning()])])
+                          DataChecks([MockDataCheckErrorAndWarning])])
 @patch('evalml.pipelines.BinaryClassificationPipeline.score')
 @patch('evalml.pipelines.BinaryClassificationPipeline.fit')
 def test_automl_data_checks_raises_error(mock_fit, mock_score, data_checks, caplog):
     X = pd.DataFrame()
     y = pd.Series()
 
-    automl = AutoMLSearch(problem_type="binary", max_pipelines=1)
+    automl = AutoMLSearch(problem_type="binary", max_iterations=1)
 
     with pytest.raises(ValueError, match="Data checks raised"):
         automl.search(X, y, data_checks=data_checks)
@@ -363,7 +373,7 @@ def test_automl_bad_data_check_parameter_type():
     X = pd.DataFrame()
     y = pd.Series()
 
-    automl = AutoMLSearch(problem_type="binary", max_pipelines=1)
+    automl = AutoMLSearch(problem_type="binary", max_iterations=1)
 
     with pytest.raises(ValueError, match="Parameter data_checks must be a list. Received int."):
         automl.search(X, y, data_checks=1)
@@ -374,6 +384,8 @@ def test_automl_bad_data_check_parameter_type():
         automl.search(X, y, data_checks="default")
     with pytest.raises(ValueError, match="All elements of parameter data_checks must be an instance of DataCheck."):
         automl.search(X, y, data_checks=[DataChecks([]), 1])
+    with pytest.raises(ValueError, match="All elements of parameter data_checks must be an instance of DataCheck."):
+        automl.search(X, y, data_checks=[MockDataCheckErrorAndWarning])
 
 
 def test_automl_str_no_param_search():
@@ -382,7 +394,7 @@ def test_automl_str_no_param_search():
     param_str_reps = {
         'Objective': 'Log Loss Binary',
         'Max Time': 'None',
-        'Max Pipelines': 'None',
+        'Max Iterations': 'None',
         'Allowed Pipelines': [],
         'Patience': 'None',
         'Tolerance': '0.0',
@@ -426,7 +438,7 @@ def test_automl_feature_selection(mock_fit, mock_score, X_y_binary):
 
     allowed_pipelines = [MockFeatureSelectionPipeline]
     start_iteration_callback = MagicMock()
-    automl = AutoMLSearch(problem_type='binary', max_pipelines=2, start_iteration_callback=start_iteration_callback, allowed_pipelines=allowed_pipelines)
+    automl = AutoMLSearch(problem_type='binary', max_iterations=2, start_iteration_callback=start_iteration_callback, allowed_pipelines=allowed_pipelines)
     automl.search(X, y)
 
     assert start_iteration_callback.call_count == 2
@@ -443,7 +455,7 @@ def test_automl_tuner_exception(mock_fit, mock_score, mock_is_search_space_exhau
     X, y = X_y_binary
     error_text = "Cannot create a unique set of unexplored parameters. Try expanding the search space."
     mock_is_search_space_exhausted.side_effect = NoParamsException(error_text)
-    clf = AutoMLSearch(problem_type='regression', objective="R2", tuner_class=RandomSearchTuner, max_pipelines=10)
+    clf = AutoMLSearch(problem_type='regression', objective="R2", tuner_class=RandomSearchTuner, max_iterations=10)
     with pytest.raises(NoParamsException, match=error_text):
         clf.search(X, y)
 
@@ -455,7 +467,7 @@ def test_automl_algorithm(mock_fit, mock_score, mock_algo_next_batch, X_y_binary
     X, y = X_y_binary
     mock_score.return_value = {'Log Loss Binary': 1.0}
     mock_algo_next_batch.side_effect = StopIteration("that's all, folks")
-    automl = AutoMLSearch(problem_type='binary', max_pipelines=5)
+    automl = AutoMLSearch(problem_type='binary', max_iterations=5)
     automl.search(X, y)
     assert automl.data_check_results is None
     mock_fit.assert_called()
@@ -472,21 +484,21 @@ def test_automl_allowed_pipelines_algorithm(mock_algo_init, dummy_binary_pipelin
     X, y = X_y_binary
 
     allowed_pipelines = [dummy_binary_pipeline_class]
-    automl = AutoMLSearch(problem_type='binary', allowed_pipelines=allowed_pipelines, max_pipelines=10)
+    automl = AutoMLSearch(problem_type='binary', allowed_pipelines=allowed_pipelines, max_iterations=10)
     with pytest.raises(Exception, match='mock algo init'):
         automl.search(X, y)
     assert mock_algo_init.call_count == 1
     _, kwargs = mock_algo_init.call_args
-    assert kwargs['max_pipelines'] == 10
+    assert kwargs['max_iterations'] == 10
     assert kwargs['allowed_pipelines'] == allowed_pipelines
 
     allowed_model_families = [ModelFamily.RANDOM_FOREST]
-    automl = AutoMLSearch(problem_type='binary', allowed_model_families=allowed_model_families, max_pipelines=1)
+    automl = AutoMLSearch(problem_type='binary', allowed_model_families=allowed_model_families, max_iterations=1)
     with pytest.raises(Exception, match='mock algo init'):
         automl.search(X, y)
     assert mock_algo_init.call_count == 2
     _, kwargs = mock_algo_init.call_args
-    assert kwargs['max_pipelines'] == 1
+    assert kwargs['max_iterations'] == 1
     for actual, expected in zip(kwargs['allowed_pipelines'], [make_pipeline(X, y, estimator, ProblemTypes.BINARY) for estimator in get_estimators(ProblemTypes.BINARY, model_families=allowed_model_families)]):
         assert actual.parameters == expected.parameters
 
@@ -494,12 +506,12 @@ def test_automl_allowed_pipelines_algorithm(mock_algo_init, dummy_binary_pipelin
 def test_automl_serialization(X_y_binary, tmpdir):
     X, y = X_y_binary
     path = os.path.join(str(tmpdir), 'automl.pkl')
-    num_max_pipelines = 5
-    automl = AutoMLSearch(problem_type='binary', max_pipelines=num_max_pipelines)
+    num_max_iterations = 5
+    automl = AutoMLSearch(problem_type='binary', max_iterations=num_max_iterations)
     automl.search(X, y)
     automl.save(path)
     loaded_automl = automl.load(path)
-    for i in range(num_max_pipelines):
+    for i in range(num_max_iterations):
         assert automl.get_pipeline(i).__class__ == loaded_automl.get_pipeline(i).__class__
         assert automl.get_pipeline(i).parameters == loaded_automl.get_pipeline(i).parameters
         assert automl.results == loaded_automl.results
@@ -509,7 +521,7 @@ def test_automl_serialization(X_y_binary, tmpdir):
 @patch('cloudpickle.dump')
 def test_automl_serialization_protocol(mock_cloudpickle_dump, tmpdir):
     path = os.path.join(str(tmpdir), 'automl.pkl')
-    automl = AutoMLSearch(problem_type='binary', max_pipelines=5)
+    automl = AutoMLSearch(problem_type='binary', max_iterations=5)
 
     automl.save(path)
     assert len(mock_cloudpickle_dump.call_args_list) == 1
@@ -538,17 +550,17 @@ def test_large_dataset_binary(mock_score):
                           objective=fraud_objective,
                           additional_objectives=['auc', 'f1', 'precision'],
                           max_time=1,
-                          max_pipelines=1,
+                          max_iterations=1,
                           optimize_thresholds=True)
     mock_score.return_value = {automl.objective.name: 1.234}
     assert automl.data_split is None
     automl.search(X, y)
     assert isinstance(automl.data_split, TrainingValidationSplit)
     assert automl.data_split.get_n_splits() == 1
-
     for pipeline_id in automl.results['search_order']:
         assert len(automl.results['pipeline_results'][pipeline_id]['cv_data']) == 1
         assert automl.results['pipeline_results'][pipeline_id]['cv_data'][0]['score'] == 1.234
+        assert automl.results['pipeline_results'][pipeline_id]['score'] == automl.results['pipeline_results'][pipeline_id]['validation_score']
 
 
 @patch('evalml.pipelines.MulticlassClassificationPipeline.score')
@@ -556,7 +568,7 @@ def test_large_dataset_multiclass(mock_score):
     X = pd.DataFrame({'col_0': [i for i in range(101000)]})
     y = pd.Series([i % 4 for i in range(101000)])
 
-    automl = AutoMLSearch(problem_type='multiclass', max_time=1, max_pipelines=1)
+    automl = AutoMLSearch(problem_type='multiclass', max_time=1, max_iterations=1)
     mock_score.return_value = {automl.objective.name: 1.234}
     assert automl.data_split is None
     automl.search(X, y)
@@ -566,6 +578,7 @@ def test_large_dataset_multiclass(mock_score):
     for pipeline_id in automl.results['search_order']:
         assert len(automl.results['pipeline_results'][pipeline_id]['cv_data']) == 1
         assert automl.results['pipeline_results'][pipeline_id]['cv_data'][0]['score'] == 1.234
+        assert automl.results['pipeline_results'][pipeline_id]['score'] == automl.results['pipeline_results'][pipeline_id]['validation_score']
 
 
 @patch('evalml.pipelines.RegressionPipeline.score')
@@ -573,7 +586,7 @@ def test_large_dataset_regression(mock_score):
     X = pd.DataFrame({'col_0': [i for i in range(101000)]})
     y = pd.Series([i for i in range(101000)])
 
-    automl = AutoMLSearch(problem_type='regression', max_time=1, max_pipelines=1)
+    automl = AutoMLSearch(problem_type='regression', max_time=1, max_iterations=1)
     mock_score.return_value = {automl.objective.name: 1.234}
     assert automl.data_split is None
     automl.search(X, y)
@@ -583,6 +596,39 @@ def test_large_dataset_regression(mock_score):
     for pipeline_id in automl.results['search_order']:
         assert len(automl.results['pipeline_results'][pipeline_id]['cv_data']) == 1
         assert automl.results['pipeline_results'][pipeline_id]['cv_data'][0]['score'] == 1.234
+        assert automl.results['pipeline_results'][pipeline_id]['score'] == automl.results['pipeline_results'][pipeline_id]['validation_score']
+
+
+@patch('evalml.pipelines.BinaryClassificationPipeline.fit')
+@patch('evalml.pipelines.BinaryClassificationPipeline.score')
+def test_large_dataset_split_size(mock_fit, mock_score):
+    def generate_fake_dataset(rows):
+        X = pd.DataFrame({'col_0': [i for i in range(rows)]})
+        y = pd.Series([i % 2 for i in range(rows)])
+        return X, y
+
+    fraud_objective = FraudCost(amount_col='col_0')
+
+    automl = AutoMLSearch(problem_type='binary',
+                          objective=fraud_objective,
+                          additional_objectives=['auc', 'f1', 'precision'],
+                          max_time=1,
+                          max_pipelines=1,
+                          optimize_thresholds=True)
+    mock_score.return_value = {automl.objective.name: 1.234}
+    assert automl.data_split is None
+
+    under_max_rows = automl._LARGE_DATA_ROW_THRESHOLD - 1
+    X, y = generate_fake_dataset(under_max_rows)
+    automl.search(X, y)
+    assert isinstance(automl.data_split, StratifiedKFold)
+
+    automl.data_split = None
+    over_max_rows = automl._LARGE_DATA_ROW_THRESHOLD + 1
+    X, y = generate_fake_dataset(over_max_rows)
+    automl.search(X, y)
+    assert isinstance(automl.data_split, TrainingValidationSplit)
+    assert automl.data_split.test_size == (automl._LARGE_DATA_PERCENT_VALIDATION)
 
 
 def test_allowed_pipelines_with_incorrect_problem_type(dummy_binary_pipeline_class):
@@ -648,7 +694,7 @@ def test_add_to_rankings(mock_fit, mock_score, dummy_binary_pipeline_class, X_y_
     X, y = X_y_binary
     mock_score.return_value = {'Log Loss Binary': 1.0}
 
-    automl = AutoMLSearch(problem_type='binary', max_pipelines=1, allowed_pipelines=[dummy_binary_pipeline_class])
+    automl = AutoMLSearch(problem_type='binary', max_iterations=1, allowed_pipelines=[dummy_binary_pipeline_class])
     automl.search(X, y)
 
     mock_score.return_value = {'Log Loss Binary': 0.1234}
@@ -664,7 +710,7 @@ def test_add_to_rankings(mock_fit, mock_score, dummy_binary_pipeline_class, X_y_
 @patch('evalml.pipelines.BinaryClassificationPipeline.fit')
 def test_add_to_rankings_no_search(mock_fit, mock_score, dummy_binary_pipeline_class, X_y_binary):
     X, y = X_y_binary
-    automl = AutoMLSearch(problem_type='binary', max_pipelines=1, allowed_pipelines=[dummy_binary_pipeline_class])
+    automl = AutoMLSearch(problem_type='binary', max_iterations=1, allowed_pipelines=[dummy_binary_pipeline_class])
 
     mock_score.return_value = {'Log Loss Binary': 0.1234}
     test_pipeline = dummy_binary_pipeline_class(parameters={})
@@ -678,7 +724,7 @@ def test_add_to_rankings_duplicate(mock_fit, mock_score, dummy_binary_pipeline_c
     X, y = X_y_binary
     mock_score.return_value = {'Log Loss Binary': 0.1234}
 
-    automl = AutoMLSearch(problem_type='binary', max_pipelines=1, allowed_pipelines=[dummy_binary_pipeline_class])
+    automl = AutoMLSearch(problem_type='binary', max_iterations=1, allowed_pipelines=[dummy_binary_pipeline_class])
     automl.search(X, y)
 
     test_pipeline = dummy_binary_pipeline_class(parameters={})
@@ -694,7 +740,7 @@ def test_add_to_rankings_trained(mock_fit, mock_score, dummy_binary_pipeline_cla
     X, y = X_y_binary
     mock_score.return_value = {'Log Loss Binary': 1.0}
 
-    automl = AutoMLSearch(problem_type='binary', max_pipelines=1, allowed_pipelines=[dummy_binary_pipeline_class])
+    automl = AutoMLSearch(problem_type='binary', max_iterations=1, allowed_pipelines=[dummy_binary_pipeline_class])
     automl.search(X, y)
 
     mock_score.return_value = {'Log Loss Binary': 0.1234}
@@ -716,7 +762,7 @@ def test_add_to_rankings_trained(mock_fit, mock_score, dummy_binary_pipeline_cla
 def test_has_searched(mock_fit, mock_score, dummy_binary_pipeline_class, X_y_binary):
     X, y = X_y_binary
 
-    automl = AutoMLSearch(problem_type='binary', max_pipelines=1)
+    automl = AutoMLSearch(problem_type='binary', max_iterations=1)
     mock_score.return_value = {automl.objective.name: 1.0}
     assert not automl.has_searched
 
@@ -729,7 +775,7 @@ def test_no_search():
     assert isinstance(automl.rankings, pd.DataFrame)
     assert isinstance(automl.full_rankings, pd.DataFrame)
 
-    df_columns = ["id", "pipeline_name", "score", "percent_better_than_baseline",
+    df_columns = ["id", "pipeline_name", "score", "validation_score", "percent_better_than_baseline",
                   "high_variance_cv", "parameters"]
     assert (automl.rankings.columns == df_columns).all()
     assert (automl.full_rankings.columns == df_columns).all()
@@ -756,14 +802,14 @@ def test_get_pipeline_invalid(mock_fit, mock_score, X_y_binary):
     with pytest.raises(PipelineNotFoundError, match="Pipeline not found in automl results"):
         automl.get_pipeline(1000)
 
-    automl = AutoMLSearch(problem_type='binary', max_pipelines=1)
+    automl = AutoMLSearch(problem_type='binary', max_iterations=1)
     automl.search(X, y)
     assert automl.get_pipeline(0).name == 'Mode Baseline Binary Classification Pipeline'
     automl._results['pipeline_results'][0].pop('pipeline_class')
     with pytest.raises(PipelineNotFoundError, match="Pipeline class or parameters not found in automl results"):
         automl.get_pipeline(0)
 
-    automl = AutoMLSearch(problem_type='binary', max_pipelines=1)
+    automl = AutoMLSearch(problem_type='binary', max_iterations=1)
     automl.search(X, y)
     assert automl.get_pipeline(0).name == 'Mode Baseline Binary Classification Pipeline'
     automl._results['pipeline_results'][0].pop('parameters')
@@ -777,7 +823,7 @@ def test_describe_pipeline(mock_fit, mock_score, caplog, X_y_binary):
     X, y = X_y_binary
     mock_score.return_value = {'Log Loss Binary': 1.0}
 
-    automl = AutoMLSearch(problem_type='binary', max_pipelines=1)
+    automl = AutoMLSearch(problem_type='binary', max_iterations=1)
     automl.search(X, y)
     out = caplog.text
 
@@ -788,7 +834,7 @@ def test_describe_pipeline(mock_fit, mock_score, caplog, X_y_binary):
     automl.describe_pipeline(0)
     out = caplog.text
     assert "Mode Baseline Binary Classification Pipeline" in out
-    assert "Problem Type: Binary Classification" in out
+    assert "Problem Type: binary" in out
     assert "Model Family: Baseline" in out
     assert "* strategy : mode" in out
     assert "Total training time (including CV): " in out
@@ -805,7 +851,7 @@ def test_describe_pipeline(mock_fit, mock_score, caplog, X_y_binary):
 @patch('evalml.pipelines.BinaryClassificationPipeline.fit')
 def test_results_getter(mock_fit, mock_score, caplog, X_y_binary):
     X, y = X_y_binary
-    automl = AutoMLSearch(problem_type='binary', max_pipelines=1)
+    automl = AutoMLSearch(problem_type='binary', max_iterations=1)
 
     assert automl.results == {'pipeline_results': {}, 'search_order': []}
 
@@ -841,7 +887,7 @@ def test_targets_data_types_classification(automl_type, target_type):
 
     unique_vals = y.unique()
 
-    automl = AutoMLSearch(problem_type=automl_type, max_pipelines=3)
+    automl = AutoMLSearch(problem_type=automl_type, max_iterations=3)
     automl.search(X, y)
     for pipeline_id, pipeline_result in automl.results['pipeline_results'].items():
         cv_data = pipeline_result['cv_data']
@@ -907,7 +953,7 @@ def test_catch_keyboard_interrupt(mock_fit, mock_score, mock_input,
     mock_input.side_effect = user_input
     X, y = X_y_binary
     callback = KeyboardInterruptOnKthPipeline(k=when_to_interrupt)
-    automl = AutoMLSearch(problem_type="binary", max_pipelines=5, start_iteration_callback=callback, objective="f1")
+    automl = AutoMLSearch(problem_type="binary", max_iterations=5, start_iteration_callback=callback, objective="f1")
     automl.search(X, y)
 
     assert len(automl._results['pipeline_results']) == number_results
@@ -953,17 +999,20 @@ def test_error_during_train_test_split(mock_fit, mock_score, mock_train_test_spl
     X, y = X_y_binary
     mock_score.return_value = {'Log Loss Binary': 1.0}
     mock_train_test_split.side_effect = RuntimeError()
-    automl = AutoMLSearch(problem_type='binary', objective='Accuracy Binary', max_pipelines=2, optimize_thresholds=True)
+    automl = AutoMLSearch(problem_type='binary', objective='Accuracy Binary', max_iterations=2, optimize_thresholds=True)
     automl.search(X, y)
     for pipeline in automl.results['pipeline_results'].values():
         assert np.isnan(pipeline['score'])
 
 
-@pytest.mark.parametrize("objective_tuple,pipeline_scores,baseline_score",
-                         product(_all_objectives_dict().items(),
+all_objectives = get_core_objectives("binary") + get_core_objectives("multiclass") + get_core_objectives("regression")
+
+
+@pytest.mark.parametrize("objective,pipeline_scores,baseline_score",
+                         product(all_objectives + [CostBenefitMatrix],
                                  [(0.3, 0.4), (np.nan, 0.4), (0.3, np.nan), (np.nan, np.nan)],
                                  [0.1, np.nan]))
-def test_percent_better_than_baseline_in_rankings(objective_tuple, pipeline_scores, baseline_score,
+def test_percent_better_than_baseline_in_rankings(objective, pipeline_scores, baseline_score,
                                                   dummy_binary_pipeline_class, dummy_multiclass_pipeline_class,
                                                   dummy_regression_pipeline_class,
                                                   X_y_binary):
@@ -971,11 +1020,6 @@ def test_percent_better_than_baseline_in_rankings(objective_tuple, pipeline_scor
     # Ok to only use binary labels since score and fit methods are mocked
     X, y = X_y_binary
 
-    name, objective = objective_tuple
-
-    if objective in AutoMLSearch._objectives_not_allowed_in_automl and name != "cost benefit matrix":
-        pytest.skip(f"Skipping because {name} is not allowed in automl as a string.")
-
     pipeline_class = {ProblemTypes.BINARY: dummy_binary_pipeline_class,
                       ProblemTypes.MULTICLASS: dummy_multiclass_pipeline_class,
                       ProblemTypes.REGRESSION: dummy_regression_pipeline_class}[objective.problem_type]
@@ -1001,12 +1045,12 @@ def test_percent_better_than_baseline_in_rankings(objective_tuple, pipeline_scor
     Pipeline1.score = mock_score_1
     Pipeline2.score = mock_score_2
 
-    if name == "cost benefit matrix":
-        automl = AutoMLSearch(problem_type=objective.problem_type, max_pipelines=3,
+    if objective.name.lower() == "cost benefit matrix":
+        automl = AutoMLSearch(problem_type=objective.problem_type, max_iterations=3,
                               allowed_pipelines=[Pipeline1, Pipeline2], objective=objective(0, 0, 0, 0))
     else:
-        automl = AutoMLSearch(problem_type=objective.problem_type, max_pipelines=3,
-                              allowed_pipelines=[Pipeline1, Pipeline2], objective=name)
+        automl = AutoMLSearch(problem_type=objective.problem_type, max_iterations=3,
+                              allowed_pipelines=[Pipeline1, Pipeline2], objective=objective)
 
     with patch(baseline_pipeline_class + ".score", return_value={objective.name: baseline_score}):
         automl.search(X, y, data_checks=None)
@@ -1025,7 +1069,7 @@ def test_percent_better_than_baseline_in_rankings(objective_tuple, pipeline_scor
 def test_max_batches_works(mock_pipeline_fit, mock_score, max_batches, X_y_binary):
     X, y = X_y_binary
 
-    automl = AutoMLSearch(problem_type="binary", max_pipelines=None,
+    automl = AutoMLSearch(problem_type="binary", max_iterations=None,
                           _max_batches=max_batches, objective="Log Loss Binary")
     automl.search(X, y, data_checks=None)
 
@@ -1034,7 +1078,7 @@ def test_max_batches_works(mock_pipeline_fit, mock_score, max_batches, X_y_binar
         max_batches = 1
         # _automl_algorithm will include all allowed_pipelines in the first batch even
         # if they are not searched over. That is why n_automl_pipelines does not equal
-        # n_results when max_pipelines and max_batches are None
+        # n_results when max_iterations and max_batches are None
         n_automl_pipelines = 1 + len(automl.allowed_pipelines)
     else:
         # So that the test does not break when new estimator classes are added
@@ -1059,14 +1103,14 @@ def test_max_batches_plays_nice_with_other_stopping_criteria(mock_fit, mock_scor
     automl.search(X, y, data_checks=None)
     assert len(automl.results["pipeline_results"]) == 5
 
-    # Use max_pipelines when both max_pipelines and max_batches are set
+    # Use max_iterations when both max_iterations and max_batches are set
     automl = AutoMLSearch(problem_type="binary", objective="Log Loss Binary", _max_batches=10,
-                          max_pipelines=6)
+                          max_iterations=6)
     automl.search(X, y, data_checks=None)
     assert len(automl.results["pipeline_results"]) == 6
 
-    # Don't change max_pipelines when only max_pipelines is set
-    automl = AutoMLSearch(problem_type="binary", max_pipelines=4)
+    # Don't change max_iterations when only max_iterations is set
+    automl = AutoMLSearch(problem_type="binary", max_iterations=4)
     automl.search(X, y, data_checks=None)
     assert len(automl.results["pipeline_results"]) == 4
 
@@ -1074,9 +1118,70 @@ def test_max_batches_plays_nice_with_other_stopping_criteria(mock_fit, mock_scor
 @pytest.mark.parametrize("max_batches", [0, -1, -10, -np.inf])
 def test_max_batches_must_be_non_negative(max_batches):
 
-    with pytest.raises(ValueError, match="Parameter max batches must be None or non-negative. Received {max_batches}."):
+    with pytest.raises(ValueError, match=f"Parameter max batches must be None or non-negative. Received {max_batches}."):
         AutoMLSearch(problem_type="binary", _max_batches=max_batches)
 
 
-def test_can_print_out_automl_objective_names():
-    AutoMLSearch.print_objective_names_allowed_in_automl()
+def test_data_split_binary(X_y_binary):
+    X, y = X_y_binary
+    y[:] = 0
+    y[0] = 1
+
+    automl = AutoMLSearch(problem_type='binary')
+    with pytest.raises(Exception, match="Missing target values in the"):
+        automl.search(X, y)
+    with pytest.raises(Exception, match="Missing target values in the"):
+        automl.search(X, y, data_checks="disabled")
+
+    y[1] = 1
+    with pytest.raises(Exception, match="Missing target values in the"):
+        automl.search(X, y)
+    with pytest.raises(Exception, match="Missing target values in the"):
+        automl.search(X, y, data_checks="disabled")
+
+    y[2] = 1
+    automl.search(X, y, data_checks="disabled")
+
+
+def test_data_split_multi(X_y_multi):
+    X, y = X_y_multi
+    y[:] = 1
+    y[0] = 0
+
+    automl = AutoMLSearch(problem_type='multiclass')
+    with pytest.raises(Exception, match="Missing target values"):
+        automl.search(X, y)
+    with pytest.raises(Exception, match="Missing target values"):
+        automl.search(X, y, data_checks="disabled")
+
+    y[1] = 2
+    # match based on regex, since data split doesn't have a random seed for reproducibility
+    # regex matches the set {} and expects either 2 sets (missing in both train and test)
+    #   or 1 set of multiple elements (both missing in train or both in test)
+    with pytest.raises(Exception, match=r"(\{\d?\}.+\{\d?\})|(\{.+\,.+\})"):
+        automl.search(X, y)
+    with pytest.raises(Exception, match=r"(\{\d?\}.+\{\d?\})|(\{.+\,.+\})"):
+        automl.search(X, y, data_checks="disabled")
+
+    y[1] = 0
+    y[2:4] = 2
+    with pytest.raises(Exception, match="Missing target values"):
+        automl.search(X, y, data_checks="disabled")
+
+    y[4] = 2
+    with pytest.raises(Exception, match="Missing target values"):
+        automl.search(X, y, data_checks="disabled")
+
+    y[5] = 0
+    automl.search(X, y, data_checks="disabled")
+
+
+def test_get_default_primary_search_objective():
+    assert isinstance(get_default_primary_search_objective("binary"), LogLossBinary)
+    assert isinstance(get_default_primary_search_objective(ProblemTypes.BINARY), LogLossBinary)
+    assert isinstance(get_default_primary_search_objective("multiclass"), LogLossMulticlass)
+    assert isinstance(get_default_primary_search_objective(ProblemTypes.MULTICLASS), LogLossMulticlass)
+    assert isinstance(get_default_primary_search_objective("regression"), R2)
+    assert isinstance(get_default_primary_search_objective(ProblemTypes.REGRESSION), R2)
+    with pytest.raises(KeyError, match="Problem type 'auto' does not exist"):
+        get_default_primary_search_objective("auto")
