@@ -371,3 +371,13 @@ def test_ohe_categories():
     np.testing.assert_array_equal(ohe.categories('col_2'), np.array(['a', 'b']))
     with pytest.raises(ValueError, match='Feature "col_12345" was not provided to one-hot encoder as a training feature'):
         ohe.categories('col_12345')
+
+
+def test_ohe_get_feature_names():
+    X = pd.DataFrame({'col_1': ['a'] * 10,
+                      'col_2': ['a'] * 3 + ['b'] * 3 + ['c'] * 2 + ['d'] * 2})
+    ohe = OneHotEncoder(top_n=2)
+    with pytest.raises(ComponentNotYetFittedError, match='This OneHotEncoder is not fitted yet. You must fit OneHotEncoder before calling get_feature_names.'):
+        ohe.get_feature_names()
+    ohe.fit(X)
+    np.testing.assert_array_equal(ohe.get_feature_names(), np.array(['col_1_a', 'col_2_a', 'col_2_b']))
