@@ -10,16 +10,15 @@ from evalml.data_checks.class_imbalance_data_check import (
 
 def test_class_imbalance_invalid_threshold():
     X = pd.DataFrame()
-    class_imbalance_check = ClassImbalanceDataCheck()
 
     with pytest.raises(ValueError, match="threshold 0 is not within the range"):
-        class_imbalance_check.validate(X, y=pd.Series([0, 1, 1]), threshold=0)
+        ClassImbalanceDataCheck(threshold=0).validate(X, y=pd.Series([0, 1, 1]))
 
     with pytest.raises(ValueError, match="threshold 0.51 is not within the range"):
-        class_imbalance_check.validate(X, y=pd.Series([0, 1, 1]), threshold=0.51)
+        ClassImbalanceDataCheck(threshold=0.51).validate(X, y=pd.Series([0, 1, 1]))
 
     with pytest.raises(ValueError, match="threshold -0.5 is not within the range"):
-        class_imbalance_check.validate(X, y=pd.Series([0, 1, 1]), threshold=-0.5)
+        ClassImbalanceDataCheck(threshold=-0.5).validate(X, y=pd.Series([0, 1, 1]))
 
 
 def test_class_imbalance_data_check_binary():
@@ -29,7 +28,7 @@ def test_class_imbalance_data_check_binary():
     assert class_imbalance_check.validate(X, y=[0, 1, 1]) == []
     assert class_imbalance_check.validate(X, y=pd.Series([0, 1, 1])) == []
     assert class_imbalance_check.validate(X, y=pd.Series([0, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1])) == [DataCheckWarning("The following labels fall below 10% of the target: [0]", "ClassImbalanceDataCheck")]
-    assert class_imbalance_check.validate(X, y=pd.Series([0, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1]), threshold=0.25) == [DataCheckWarning("The following labels fall below 25% of the target: [0]", "ClassImbalanceDataCheck")]
+    assert ClassImbalanceDataCheck(threshold=0.25).validate(X, y=pd.Series([0, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1])) == [DataCheckWarning("The following labels fall below 25% of the target: [0]", "ClassImbalanceDataCheck")]
 
 
 def test_class_imbalance_data_check_multiclass():
@@ -38,7 +37,7 @@ def test_class_imbalance_data_check_multiclass():
 
     assert class_imbalance_check.validate(X, y=pd.Series([0, 2, 1, 1])) == []
     assert class_imbalance_check.validate(X, y=pd.Series([0, 2, 2, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1])) == [DataCheckWarning("The following labels fall below 10% of the target: [0]", "ClassImbalanceDataCheck")]
-    assert class_imbalance_check.validate(X, y=pd.Series([0, 2, 2, 2, 3, 3, 1, 1, 1, 1]), threshold=0.25) == [DataCheckWarning("The following labels fall below 25% of the target: [3, 0]", "ClassImbalanceDataCheck")]
+    assert ClassImbalanceDataCheck(threshold=0.25).validate(X, y=pd.Series([0, 2, 2, 2, 3, 3, 1, 1, 1, 1])) == [DataCheckWarning("The following labels fall below 25% of the target: [3, 0]", "ClassImbalanceDataCheck")]
 
 
 def test_class_imbalance_empty_and_nan():
@@ -46,13 +45,13 @@ def test_class_imbalance_empty_and_nan():
     class_imbalance_check = ClassImbalanceDataCheck()
 
     assert class_imbalance_check.validate(X, y=pd.Series([])) == []
-    assert class_imbalance_check.validate(X, y=pd.Series([np.nan, np.nan, np.nan, np.nan, 1, 1, 1, 1, 2]), threshold=0.5) == [DataCheckWarning("The following labels fall below 50% of the target: [2.0]", "ClassImbalanceDataCheck")]
+    assert ClassImbalanceDataCheck(threshold=0.5).validate(X, y=pd.Series([np.nan, np.nan, np.nan, np.nan, 1, 1, 1, 1, 2])) == [DataCheckWarning("The following labels fall below 50% of the target: [2.0]", "ClassImbalanceDataCheck")]
 
 
 def test_class_imbalance_nonnumeric():
     X = pd.DataFrame()
-    class_imbalance_check = ClassImbalanceDataCheck()
+    class_imbalance_check = ClassImbalanceDataCheck(threshold=0.25)
 
-    assert class_imbalance_check.validate(X, y=[True, False, False, False, False], threshold=0.25) == [DataCheckWarning("The following labels fall below 25% of the target: [True]", "ClassImbalanceDataCheck")]
-    assert class_imbalance_check.validate(X, y=["yes", "no", "yes", "yes", "yes"], threshold=0.25) == [DataCheckWarning("The following labels fall below 25% of the target: ['no']", "ClassImbalanceDataCheck")]
-    assert class_imbalance_check.validate(X, y=["red", "green", "red", "red", "blue", "green", "red", "blue", "green", "red"], threshold=0.35) == [DataCheckWarning("The following labels fall below 35% of the target: ['green', 'blue']", "ClassImbalanceDataCheck")]
+    assert class_imbalance_check.validate(X, y=[True, False, False, False, False]) == [DataCheckWarning("The following labels fall below 25% of the target: [True]", "ClassImbalanceDataCheck")]
+    assert class_imbalance_check.validate(X, y=["yes", "no", "yes", "yes", "yes"]) == [DataCheckWarning("The following labels fall below 25% of the target: ['no']", "ClassImbalanceDataCheck")]
+    assert ClassImbalanceDataCheck(threshold=0.35).validate(X, y=["red", "green", "red", "red", "blue", "green", "red", "blue", "green", "red"]) == [DataCheckWarning("The following labels fall below 35% of the target: ['green', 'blue']", "ClassImbalanceDataCheck")]
