@@ -12,7 +12,7 @@ def test_lead_scoring_objective(X_y_binary):
     objective = LeadScoring(true_positives=1,
                             false_positives=-1)
 
-    automl = AutoMLSearch(problem_type='binary', objective=objective, max_pipelines=1, random_state=0)
+    automl = AutoMLSearch(problem_type='binary', objective=objective, max_iterations=1, random_state=0)
     automl.search(X, y)
     pipeline = automl.best_pipeline
     pipeline.fit(X, y)
