@@ -59,10 +59,8 @@ def test_allowed_model_families(has_minimal_dependencies):
     expected_model_families_binary = set(families)
     expected_model_families_regression = set(families)
     if not has_minimal_dependencies:
-        expected_model_families_binary.add(ModelFamily.XGBOOST)
-        expected_model_families_binary.add(ModelFamily.CATBOOST)
-        expected_model_families_regression.add(ModelFamily.CATBOOST)
-        expected_model_families_regression.add(ModelFamily.XGBOOST)
+        expected_model_families_binary.update([ModelFamily.XGBOOST, ModelFamily.CATBOOST, ModelFamily.LIGHTGBM])
+        expected_model_families_regression.update([ModelFamily.CATBOOST, ModelFamily.XGBOOST])
     assert set(allowed_model_families(ProblemTypes.BINARY)) == expected_model_families_binary
     assert set(allowed_model_families(ProblemTypes.REGRESSION)) == expected_model_families_regression
 
@@ -71,7 +69,7 @@ def test_all_estimators(has_minimal_dependencies):
     if has_minimal_dependencies:
         assert len((_all_estimators_used_in_search())) == 8
     else:
-        assert len(_all_estimators_used_in_search()) == 12
+        assert len(_all_estimators_used_in_search()) == 13
 
 
 def test_get_estimators(has_minimal_dependencies):
@@ -81,9 +79,9 @@ def test_get_estimators(has_minimal_dependencies):
         assert len(get_estimators(problem_type=ProblemTypes.MULTICLASS)) == 4
         assert len(get_estimators(problem_type=ProblemTypes.REGRESSION)) == 4
     else:
-        assert len(get_estimators(problem_type=ProblemTypes.BINARY)) == 6
+        assert len(get_estimators(problem_type=ProblemTypes.BINARY)) == 7
         assert len(get_estimators(problem_type=ProblemTypes.BINARY, model_families=[ModelFamily.LINEAR_MODEL])) == 2
-        assert len(get_estimators(problem_type=ProblemTypes.MULTICLASS)) == 6
+        assert len(get_estimators(problem_type=ProblemTypes.MULTICLASS)) == 7
         assert len(get_estimators(problem_type=ProblemTypes.REGRESSION)) == 6
 
     assert len(get_estimators(problem_type=ProblemTypes.BINARY, model_families=[])) == 0
@@ -244,9 +242,21 @@ def test_make_pipeline_problem_type_mismatch():
         make_pipeline(pd.DataFrame(), pd.Series(), Transformer, ProblemTypes.MULTICLASS)
 
 
-def test_make_pipeline_from_components():
+def test_make_pipeline_from_components(X_y_binary, logistic_regression_binary_pipeline_class):
     with pytest.raises(ValueError, match="Pipeline needs to have an estimator at the last position of the component list"):
-        make_pipeline_from_components([Imputer], problem_type='binary')
+        make_pipeline_from_components([Imputer()], problem_type='binary')
+
+    with pytest.raises(KeyError, match="Problem type 'invalid_type' does not exist"):
+        make_pipeline_from_components([RandomForestClassifier()], problem_type='invalid_type')
+
+    with pytest.raises(TypeError, match="Custom pipeline name must be a string"):
+        make_pipeline_from_components([RandomForestClassifier()], problem_type='binary', custom_name=True)
+
+    with pytest.raises(TypeError, match="Every element of `component_instances` must be an instance of ComponentBase"):
+        make_pipeline_from_components([RandomForestClassifier], problem_type='binary')
+
+    with pytest.raises(TypeError, match="Every element of `component_instances` must be an instance of ComponentBase"):
+        make_pipeline_from_components(['RandomForestClassifier'], problem_type='binary')
 
     imp = Imputer(numeric_impute_strategy='median')
     est = RandomForestClassifier()
@@ -280,6 +290,21 @@ def test_make_pipeline_from_components():
     expected_parameters = {'Dummy!': {'bar': 'baz'}}
     assert pipeline.parameters == expected_parameters
 
+    X, y = X_y_binary
+    pipeline = logistic_regression_binary_pipeline_class(parameters={}, random_state=np.random.RandomState(42))
+    new_pipeline = make_pipeline_from_components(pipeline.component_graph, ProblemTypes.BINARY)
+    pipeline.fit(X, y)
+    predictions = pipeline.predict(X)
+    new_pipeline.fit(X, y)
+    new_predictions = new_pipeline.predict(X)
+    assert np.array_equal(predictions, new_predictions)
+    assert np.array_equal(pipeline.feature_importance, new_pipeline.feature_importance)
+    assert new_pipeline.name == 'Templated Pipeline'
+    assert pipeline.parameters == new_pipeline.parameters
+    for component, new_component in zip(pipeline.component_graph, new_pipeline.component_graph):
+        assert isinstance(new_component, type(component))
+    assert pipeline.describe() == new_pipeline.describe()
+
 
 def test_required_fields():
     class TestPipelineWithoutComponentGraph(PipelineBase):
@@ -386,7 +411,7 @@ def test_describe(caplog, logistic_regression_binary_pipeline_class):
     lrp.describe()
     out = caplog.text
     assert "Logistic Regression Binary Pipeline" in out
-    assert "Problem Type: Binary Classification" in out
+    assert "Problem Type: binary" in out
     assert "Model Family: Linear" in out
     assert "Number of features: " not in out
 
@@ -404,7 +429,7 @@ def test_describe_fitted(X_y_binary, caplog, logistic_regression_binary_pipeline
     lrp.describe()
     out = caplog.text
     assert "Logistic Regression Binary Pipeline" in out
-    assert "Problem Type: Binary Classification" in out
+    assert "Problem Type: binary" in out
     assert "Model Family: Linear" in out
     assert "Number of features: {}".format(X.shape[1]) in out
 
@@ -444,7 +469,9 @@ def test_parameters(logistic_regression_binary_pipeline_class):
         'Logistic Regression Classifier': {
             'penalty': 'l2',
             'C': 3.0,
-            'n_jobs': -1
+            'n_jobs': -1,
+            'multi_class': 'auto',
+            'solver': 'lbfgs'
         }
     }
     assert lrp.parameters == expected_parameters
@@ -837,11 +864,19 @@ def test_hyperparameters_override():
 
 
 def test_hyperparameters_none(dummy_classifier_estimator_class):
-    MockEstimator = dummy_classifier_estimator_class
+    class MockEstimator(Estimator):
+        name = "Mock Classifier"
+        model_family = ModelFamily.NONE
+        supported_problem_types = [ProblemTypes.BINARY, ProblemTypes.MULTICLASS]
+        hyperparameter_ranges = {}
+
+        def __init__(self, random_state=0):
+            super().__init__(parameters={}, component_obj=None, random_state=random_state)
 
     class MockPipelineNone(BinaryClassificationPipeline):
         component_graph = [MockEstimator]
 
+    assert MockPipelineNone.component_graph == [MockEstimator]
     assert MockPipelineNone.hyperparameters == {'Mock Classifier': {}}
     assert MockPipelineNone(parameters={}).hyperparameters == {'Mock Classifier': {}}
 
@@ -860,8 +895,8 @@ def test_score_with_objective_that_requires_predict_proba(mock_predict, dummy_re
         clf.fit(X, y)
         clf.score(X, y, ['precision', 'auc'])
     except PipelineScoreError as e:
-        assert "Invalid objective AUC specified for problem type Regression" in e.message
-        assert "Invalid objective Precision specified for problem type Regression" in e.message
+        assert "Invalid objective AUC specified for problem type regression" in e.message
+        assert "Invalid objective Precision specified for problem type regression" in e.message
     mock_predict.assert_called()
 
 
@@ -1056,7 +1091,9 @@ def test_get_default_parameters(logistic_regression_binary_pipeline_class):
         'Logistic Regression Classifier': {
             'penalty': 'l2',
             'C': 1.0,
-            'n_jobs': -1
+            'n_jobs': -1,
+            'multi_class': 'auto',
+            'solver': 'lbfgs'
         }
     }
     assert logistic_regression_binary_pipeline_class.default_parameters == expected_defaults
@@ -1257,3 +1294,54 @@ def test_pipeline_equality_different_fitted_data(problem_type, X_y_binary, X_y_m
     pipeline_diff_data.fit(X, y)
 
     assert pipeline != pipeline_diff_data
+
+
+def test_pipeline_str():
+
+    class MockBinaryPipeline(BinaryClassificationPipeline):
+        name = "Mock Binary Pipeline"
+        component_graph = ['Imputer', 'Random Forest Classifier']
+
+    class MockMulticlassPipeline(MulticlassClassificationPipeline):
+        name = "Mock Multiclass Pipeline"
+        component_graph = ['Imputer', 'Random Forest Classifier']
+
+    class MockRegressionPipeline(RegressionPipeline):
+        name = "Mock Regression Pipeline"
+        component_graph = ['Imputer', 'Random Forest Regressor']
+
+    binary_pipeline = MockBinaryPipeline(parameters={})
+    multiclass_pipeline = MockMulticlassPipeline(parameters={})
+    regression_pipeline = MockRegressionPipeline(parameters={})
+
+    assert str(binary_pipeline) == "Mock Binary Pipeline"
+    assert str(multiclass_pipeline) == "Mock Multiclass Pipeline"
+    assert str(regression_pipeline) == "Mock Regression Pipeline"
+
+
+@pytest.mark.parametrize("pipeline_class", [BinaryClassificationPipeline, MulticlassClassificationPipeline, RegressionPipeline])
+def test_pipeline_repr(pipeline_class):
+    if pipeline_class in [BinaryClassificationPipeline, MulticlassClassificationPipeline]:
+        final_estimator = 'Random Forest Classifier'
+    else:
+        final_estimator = 'Random Forest Regressor'
+
+    class MockPipeline(pipeline_class):
+        name = "Mock Pipeline"
+        component_graph = ['Imputer', final_estimator]
+
+    pipeline = MockPipeline(parameters={})
+    expected_repr = f"MockPipeline(parameters={{'Imputer':{{'categorical_impute_strategy': 'most_frequent', 'numeric_impute_strategy': 'mean', 'categorical_fill_value': None, 'numeric_fill_value': None}}, '{final_estimator}':{{'n_estimators': 100, 'max_depth': 6, 'n_jobs': -1}},}})"
+    assert repr(pipeline) == expected_repr
+
+    pipeline_with_parameters = MockPipeline(parameters={'Imputer': {'numeric_fill_value': 42}})
+    expected_repr = f"MockPipeline(parameters={{'Imputer':{{'categorical_impute_strategy': 'most_frequent', 'numeric_impute_strategy': 'mean', 'categorical_fill_value': None, 'numeric_fill_value': 42}}, '{final_estimator}':{{'n_estimators': 100, 'max_depth': 6, 'n_jobs': -1}},}})"
+    assert repr(pipeline_with_parameters) == expected_repr
+
+    pipeline_with_inf_parameters = MockPipeline(parameters={'Imputer': {'numeric_fill_value': float('inf'), 'categorical_fill_value': np.inf}})
+    expected_repr = f"MockPipeline(parameters={{'Imputer':{{'categorical_impute_strategy': 'most_frequent', 'numeric_impute_strategy': 'mean', 'categorical_fill_value': float('inf'), 'numeric_fill_value': float('inf')}}, '{final_estimator}':{{'n_estimators': 100, 'max_depth': 6, 'n_jobs': -1}},}})"
+    assert repr(pipeline_with_inf_parameters) == expected_repr
+
+    pipeline_with_nan_parameters = MockPipeline(parameters={'Imputer': {'numeric_fill_value': float('nan'), 'categorical_fill_value': np.nan}})
+    expected_repr = f"MockPipeline(parameters={{'Imputer':{{'categorical_impute_strategy': 'most_frequent', 'numeric_impute_strategy': 'mean', 'categorical_fill_value': np.nan, 'numeric_fill_value': np.nan}}, '{final_estimator}':{{'n_estimators': 100, 'max_depth': 6, 'n_jobs': -1}},}})"
+    assert repr(pipeline_with_nan_parameters) == expected_repr
